@echo off
SETLOCAL ENABLEDELAYEDEXPANSION

REM Define the pin value as a variable
SET "PIN_VALUE=<Company-wide PIN>"

REM Check if the hpLHAgent service is present
echo Checking if hpLHAgent service is present...
sc query hpLHAgent >nul 2>&1
IF %ERRORLEVEL% NEQ 0 (
    echo hpLHAgent service is not present. Proceeding to install...

    REM Install with the pin value
    echo Installing with CPIN=%PIN_VALUE%...
    \\<NetworkShare>\Setup.exe /silent CPIN=%PIN_VALUE%
    goto end
)

REM The service is present, now check DeviceEnrolled status
echo hpLHAgent service is present. Checking DeviceEnrolled status...

REM Check if DeviceEnrolled key exists and contains the value True
REG QUERY "HKLM\SOFTWARE\Hewlett-Packard\HP Touchpoint Manager\Agent" /v "DeviceEnrolled" 2>&1 | find /i "True" >nul
IF %ERRORLEVEL% NEQ 0 (
    echo DeviceEnrolled registry key does not exist or value is not True. Creating enroll_config.json...

    REM Create the JSON file with the desired content using %ProgramData%
    echo {^"enroll_config^":{^"agree_to_be_managed^":true,^"enrollment_type^":^"pin^",^"pin^":^"%PIN_VALUE%^"}} > "%ProgramData%\Hewlett-Packard\HP Touchpoint Manager\enroll_config.json"
    
    echo File creation complete. Exiting...
    goto end
)

REM Query the registry for DeviceEnrolled value
FOR /F "tokens=2*" %%A IN ('REG QUERY "HKLM\SOFTWARE\Hewlett-Packard\HP Touchpoint Manager\Agent" /v "DeviceEnrolled" 2^>nul') DO (
    SET "DeviceEnrolledValue=%%B"
)
echo DeviceEnrolled value: !DeviceEnrolledValue!

IF /I "!DeviceEnrolledValue!"=="True" (
    echo Device is enrolled. Checking DeviceEntitlement...

    REM If the key exists, query the value
    FOR /F "tokens=2*" %%A IN ('REG QUERY "HKLM\SOFTWARE\Hewlett-Packard\HP Touchpoint Manager\Agent" /v "DeviceEntitlement" 2^>nul') DO (
        SET "DeviceEntitlementValue=%%B"
    )
    
    REM Check if the DeviceEntitlement value is empty (i.e., undefined or empty string)
    IF "!DeviceEntitlementValue!"=="" (
        echo DeviceEntitlement key does not exists or but value is empty. Creating enroll_config.json...

        REM Create the JSON file with the desired content using %ProgramData%
        echo {^"enroll_config^":{^"agree_to_be_managed^":true,^"enrollment_type^":^"pin^",^"pin^":^"%PIN_VALUE%^"}} > "%ProgramData%\Hewlett-Packard\HP Touchpoint Manager\enroll_config.json"
        
        echo File creation complete. Exiting...
        goto end
    )

    echo DeviceEntitlement value: !DeviceEntitlementValue!

    REM Check if DeviceEntitlement value matches "smart support"
    IF /I "!DeviceEntitlementValue!"=="smart support" (
        echo DeviceEntitlement matches "smart support". Creating enroll_config.json...

        REM Create the JSON file with the desired content using %ProgramData%
        echo {^"enroll_config^":{^"agree_to_be_managed^":true,^"enrollment_type^":^"pin^",^"pin^":^"%PIN_VALUE%^"}} > "%ProgramData%\Hewlett-Packard\HP Touchpoint Manager\enroll_config.json"
        
        echo File creation complete. Exiting...
        goto end
    )

    echo DeviceEntitlement does not match "smart support". Exiting...
    goto end
) ELSE (
    echo Device is not enrolled. Creating enroll_config.json...

    REM Create the JSON file with the desired content using %ProgramData%
    echo {^"enroll_config^":{^"agree_to_be_managed^":true,^"enrollment_type^":^"pin^",^"pin^":^"%PIN_VALUE%^"}} > "%ProgramData%\Hewlett-Packard\HP Touchpoint Manager\enroll_config.json"
    
    echo File creation complete. Exiting...
    goto end
)

:end
echo Script execution complete.
